==> taboola_sdk-0.0.4.tar.gz: example/lib/screens/taboola_custom_scrollview_screen.dart <==
import 'package:flutter/material.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/standard/taboola_standard_listener.dart';
import 'package:taboola_sdk/standard/taboola_standard.dart';
import 'package:taboola_sdk/utils/logger.dart';

class TaboolaCustomScrollviewScreen extends StatelessWidget {
  TaboolaStandardBuilder _taboolaStandardBuilder;
  TaboolaStandardListener _taboolaStandardListener;

  TaboolaStandard _taboolaStandard;

  TaboolaCustomScrollviewScreen(String publisher, String pageUrl, String pageType, String placement, String mode) {
    Taboola.init(PublisherInfo(publisher));
    _taboolaStandardBuilder = Taboola.getTaboolaStandardBuilder(pageUrl, pageType);
    _taboolaStandardListener = TaboolaStandardListener(taboolaDidResize,taboolaDidShow,taboolaDidFailToLoad,taboolaDidClickOnItem);
    _taboolaStandard = _taboolaStandardBuilder.build(placement, mode, true, _taboolaStandardListener);
  }

  @override
  Widget build(BuildContext context) {
    return CustomScrollView(
      controller: _taboolaStandard.scrollController,
      slivers: <Widget>[
        SliverList(
            delegate: new SliverChildListDelegate(_buildList(20))
        ),
        SliverToBoxAdapter(
          child: _taboolaStandard,
        ),
      ],
    );
  }

  /// Sample content.
  List _buildList(int count) {
    List<Widget> listItems = List();


    for (int i = 0; i < count; i++) {
      listItems.add(new Padding(padding: new EdgeInsets.all(20.0),
          child: new Text(
              'Item ${i.toString()}',
              style: new TextStyle(fontSize: 25.0)
          )
      ));
    }

    return listItems;
  }
  List<Widget> addEmulatorWarning(List<Widget> listItems) {
    listItems.add(new Padding(padding: new EdgeInsets.all(20.0),
        child: new Text(
            'Warning: current version of Taboola Flutter SDK has WebView-Native scroll switch issues on emulators. Please debug on a real device.',
        )
    ));

    return listItems;
  }


  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    Logger.log("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    Logger.log("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(String placement, String itemId, String clickUrl, bool organic) {
    print("publisher did cilck on item:$itemId with clickUrl:$clickUrl in placement:$placement of organic:$organic");
    return false;
  }
}

==> taboola_sdk-0.1.0.tar.gz: example/lib/screens/taboola_custom_scrollview_screen.dart <==
import 'package:flutter/material.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/standard/taboola_standard_listener.dart';
import 'package:taboola_sdk/standard/taboola_standard.dart';
import 'package:taboola_sdk/utils/logger.dart';

class TaboolaCustomScrollviewScreen extends StatelessWidget {
  TaboolaStandardBuilder _taboolaStandardBuilder;
  TaboolaStandardListener _taboolaStandardListener;

  TaboolaStandard _taboolaStandard;

  TaboolaCustomScrollviewScreen(String publisher, String pageUrl, String pageType, String placement, String mode) {
    Taboola.init(PublisherInfo(publisher));
    _taboolaStandardBuilder = Taboola.getTaboolaStandardBuilder(pageUrl, pageType);
    _taboolaStandardListener = TaboolaStandardListener(taboolaDidResize,taboolaDidShow,taboolaDidFailToLoad,taboolaDidClickOnItem);
    _taboolaStandard = _taboolaStandardBuilder.build(placement, mode, true, _taboolaStandardListener);
  }

  @override
  Widget build(BuildContext context) {
    return CustomScrollView(
      controller: _taboolaStandard.scrollController,
      slivers: <Widget>[
        SliverList(
            delegate: new SliverChildListDelegate(_buildList(20))
        ),
        SliverToBoxAdapter(
          child: _taboolaStandard,
        ),
      ],
    );
  }

  /// Sample content.
  List _buildList(int count) {
    List<Widget> listItems = List();


    for (int i = 0; i < count; i++) {
      listItems.add(new Padding(padding: new EdgeInsets.all(20.0),
          child: new Text(
              'Item ${i.toString()}',
              style: new TextStyle(fontSize: 25.0)
          )
      ));
    }

    return listItems;
  }
  List<Widget> addEmulatorWarning(List<Widget> listItems) {
    listItems.add(new Padding(padding: new EdgeInsets.all(20.0),
        child: new Text(
            'Warning: current version of Taboola Flutter SDK has WebView-Native scroll switch issues on emulators. Please debug on a real device.',
        )
    ));

    return listItems;
  }


  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    Logger.log("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    Logger.log("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(String placement, String itemId, String clickUrl, bool organic) {
    print("publisher did click on item: $itemId with clickUrl: $clickUrl in placement: $placement of organic: $organic");
    return true;
  }
}
